<?php

namespace App;

/**
 * Theme customizer
 */
add_action('customize_register', function (\WP_Customize_Manager $wp_customize) {
    // Add postMessage support
    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->selective_refresh->add_partial('blogname', [
        'selector' => '.brand',
        'render_callback' => function () {
            bloginfo('name');
        }
    ]);
});

/**
 * Customizer JS
 */
add_action('customize_preview_init', function () {
    wp_enqueue_script('sage/customizer.js', asset_path('scripts/customizer.js'), ['customize-preview'], null, true);
});

function flairstech_acf_op_init()
{

    // Check function exists.
    if (function_exists('acf_add_options_page')) {
        // Register options page.
        $option_page = acf_add_options_page(array(
            'page_title'    => __('Theme General Settings'),
            'menu_title'    => __('Theme Settings'),
            'menu_slug'     => 'theme-general-settings',
            'capability'    => 'edit_posts',
            'redirect'      => false
        ));
    }
}
add_action('acf/init', __NAMESPACE__ . '\\flairstech_acf_op_init');

/*
 * Add ACF Theme Options Groups and Fields
 */
function flairstech_acf_add_theme_options_fields()
{

    if (function_exists('acf_add_local_field_group')) :
        acf_add_local_field_group(array(
            'key' => 'group_5f218dbdda8fb',
            'title' => 'Theme Settings',
            'fields' => array(
                array(
                    'key' => 'field_5f218dce28608',
                    'label' => 'Theme Options',
                    'name' => 'theme_options',
                    'type' => 'group',
                    'instructions' => '',
                    'required' => 0,
                    'conditional_logic' => 0,
                    'wrapper' => array(
                        'width' => '',
                        'class' => '',
                        'id' => '',
                    ),
                    'layout' => 'block',
                    'sub_fields' => array(
                        array(
                            'key' => 'field_5f218dee28609',
                            'label' => 'Logo',
                            'name' => 'logo',
                            'type' => 'image',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'return_format' => 'array',
                            'preview_size' => 'medium',
                            'library' => 'all',
                            'min_width' => '',
                            'min_height' => '',
                            'min_size' => '',
                            'max_width' => '',
                            'max_height' => '',
                            'max_size' => '',
                            'mime_types' => '',
                        ),
                        array(
                            'key' => 'field_gqt4uxefnfqra',
                            'label' => 'Top Header Mail',
                            'name' => 'top_header_mail',
                            'type' => 'email',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                        ),
                        array(
                            'key' => 'field_5f6c8605z3215',
                            'label' => 'Main Menu Link',
                            'name' => 'main_menu_link',
                            'type' => 'link',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'placeholder' => '',
                            'prepend' => '',
                            'append' => '',
                            'maxlength' => '',
                        ),
                        array(
                            'key' => 'field_5fqy2qxtuztgz',
                            'label' => 'Footer Call To Action Left Text',
                            'name' => 'footer_call_to_action_left_text',
                            'type' => 'text',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                        ),
                        array(
                            'key' => 'field_5f7y3navoafqd',
                            'label' => 'Footer Call To Action Left Link',
                            'name' => 'footer_call_to_action_left_link',
                            'type' => 'link',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'placeholder' => '',
                            'prepend' => '',
                            'append' => '',
                            'maxlength' => '',
                        ),
                        array(
                            'key' => 'field_5f3rikse4cwse',
                            'label' => 'Footer Call To Action Right Text',
                            'name' => 'footer_call_to_action_right_text',
                            'type' => 'text',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                        ),
                        array(
                            'key' => 'field_5fxh5c7aaigvq',
                            'label' => 'Footer Call To Action Right Link',
                            'name' => 'footer_call_to_action_right_link',
                            'type' => 'link',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'placeholder' => '',
                            'prepend' => '',
                            'append' => '',
                            'maxlength' => '',
                        ),
                        array(
                            'key' => 'field_5f218dfa2860a',
                            'label' => 'Copyright',
                            'name' => 'copyright',
                            'type' => 'wysiwyg',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'default_value' => '',
                            'tabs' => 'all',
                            'toolbar' => 'full',
                            'media_upload' => 1,
                            'delay' => 0,
                        ),
                        array(
                            'key' => 'field_5fdraxo0ufbns',
                            'label' => 'Social Media Icons',
                            'name' => 'social_media_icons',
                            'type' => 'repeater',
                            'instructions' => '',
                            'required' => 0,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'collapsed' => '',
                            'min' => 0,
                            'max' => 0,
                            'layout' => 'table',
                            'button_label' => '',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5fei8z3jp6n93',
                                    'label' => 'Icon',
                                    'name' => 'icon',
                                    'type' => 'group',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'layout' => 'block',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5fn7959zccgtu',
                                            'label' => 'Social Media Link',
                                            'name' => 'social_media_link',
                                            'type' => 'link',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_gqtujbt7ckseb',
                                            'label' => 'Fontawesome Icon Class',
                                            'name' => 'fontawesome_icon_class',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                        ),
                                    ),
                                )
                            ),
                        ),
                    ),
                ),

            ),
            'location' => array(
                array(
                    array(
                        'param' => 'options_page',
                        'operator' => '==',
                        'value' => 'theme-general-settings',
                    ),
                ),
            ),
            'menu_order' => 0,
            'position' => 'normal',
            'style' => 'default',
            'label_placement' => 'top',
            'instruction_placement' => 'label',
            'hide_on_screen' => '',
            'active' => true,
            'description' => '',
        ));
    endif;
}

add_action('acf/init', __NAMESPACE__ . '\\flairstech_acf_add_theme_options_fields');

/*
 * Add ACF Theme Options Groups and Fields
 */
function flairstech_acf_add_theme_general_template_fields()
{
    if (function_exists('acf_add_local_field_group')) :
        acf_add_local_field_group(array(
            'key' => 'group_5f6c76743deca',
            'title' => 'General',
            'fields' => array(
                array(
                    'key' => 'field_5f6c767ae7220',
                    'label' => 'Main',
                    'name' => 'main',
                    'type' => 'flexible_content',
                    'instructions' => '',
                    'required' => 0,
                    'conditional_logic' => 0,
                    'wrapper' => array(
                        'width' => '',
                        'class' => '',
                        'id' => '',
                    ),
                    'layouts' => array(
                        'layout_5fguthugp9mxl' => array(
                            'key' => 'layout_5fguthugp9mxl',
                            'name' => 'content-carousel',
                            'label' => 'Content Carousel',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5f0a6eb950466',
                                    'label' => 'Title',
                                    'name' => 'title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => 'Let’s Get Started On Helping You Achieve<span> Your Objectives</span>',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5ffj4e6b918g4',
                                    'label' => 'Sub Title',
                                    'name' => 'sub-title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fe3luuhmqcsw',
                                    'label' => 'Images',
                                    'name' => 'images',
                                    'type' => 'repeater',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'collapsed' => '',
                                    'min' => 0,
                                    'max' => 0,
                                    'layout' => 'table',
                                    'button_label' => '',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5fovpniix3ap5',
                                            'label' => 'Image',
                                            'name' => 'image',
                                            'type' => 'image',
                                            'instructions' => '',
                                            'required' => 1,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'medium',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fpm2y9o620j8',
                                            'label' => 'Description',
                                            'name' => 'description',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 1,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fnbm1be6lj9x',
                                            'label' => 'Link',
                                            'name' => 'link',
                                            'type' => 'file',
                                            'instructions' => '',
                                            'required' => 1,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fy9k23wuvpn6',
                                            'label' => 'Content',
                                            'name' => 'content',
                                            'type' => 'repeater',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'collapsed' => '',
                                            'min' => 0,
                                            'max' => 0,
                                            'layout' => 'table',
                                            'button_label' => '',
                                            'sub_fields' => array(
                                                array(
                                                    'key' => 'field_5f5pj1w427tkb',
                                                    'label' => 'Label',
                                                    'name' => 'label',
                                                    'type' => 'text',
                                                    'instructions' => '',
                                                    'required' => 0,
                                                    'conditional_logic' => 0,
                                                    'wrapper' => array(
                                                        'width' => '',
                                                        'class' => '',
                                                        'id' => '',
                                                    ),
                                                    'default_value' => '',
                                                    'placeholder' => '',
                                                    'prepend' => '',
                                                    'append' => '',
                                                    'maxlength' => '',
                                                ),
                                                array(
                                                    'key' => 'field_5fke0gndl2t5s',
                                                    'label' => 'Value',
                                                    'name' => 'value',
                                                    'type' => 'text',
                                                    'instructions' => '',
                                                    'required' => 0,
                                                    'conditional_logic' => 0,
                                                    'wrapper' => array(
                                                        'width' => '',
                                                        'class' => '',
                                                        'id' => '',
                                                    ),
                                                    'return_format' => 'array',
                                                ),
                                            ),
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_agtav4qyw6ijo',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5fhz2apaxvqyg' => array(
                            'key' => 'layout_5fhz2apaxvqyg',
                            'name' => 'contact-form',
                            'label' => 'Contact Us Block',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5f0969a941dc7',
                                    'label' => 'Side 1',
                                    'name' => 'side_1',
                                    'type' => 'group',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'layout' => 'block',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5f0a6eb950466',
                                            'label' => 'Title',
                                            'name' => 'title',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 1,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => 'Let’s Get Started On Helping You Achieve<span> Your Objectives</span>',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5f0968f241dc6',
                                            'label' => 'contact form short code',
                                            'name' => 'contact_form_short_code',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 1,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_5f0a663e41dc8',
                                    'label' => 'Side 2',
                                    'name' => 'side_2',
                                    'type' => 'group',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'layout' => 'block',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5f0a663e41dc9',
                                            'label' => 'Title',
                                            'name' => 'title',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 1,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => 'We’d love to <br> hear <span class="w-auto"> from</span> you.',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5f0a665a41dca',
                                            'label' => 'Message',
                                            'name' => 'message',
                                            'type' => 'wysiwyg',
                                            'instructions' => '',
                                            'required' => 1,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '<p> <b>Got a project? </b> Schedule a callback from one of our experts to discuss your challenges, pain points, ideas, game plan. Just fill out the form, and we’ll be in touch within 48 hours. </p>',
                                            'tabs' => 'visual',
                                            'toolbar' => 'full',
                                            'media_upload' => 1,
                                            'delay' => 0,
                                        ),
                                        array(
                                            'key' => 'field_5f0a66b841dcb',
                                            'label' => 'background',
                                            'name' => 'background',
                                            'type' => 'image',
                                            'instructions' => '',
                                            'required' => 1,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'large',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_5f0a66e541dcc',
                                    'label' => 'Direction',
                                    'name' => 'direction',
                                    'type' => 'select',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'choices' => array(
                                        'side_one' => 'Side 1 Left',
                                        'side_two' => 'Side 2 Left',
                                    ),
                                    'default_value' => 'side_one',
                                    'allow_null' => 0,
                                    'multiple' => 0,
                                    'ui' => 0,
                                    'return_format' => 'value',
                                    'ajax' => 0,
                                    'placeholder' => '',
                                ),
                                array(
                                    'key' => 'field_agr7vd89r4xsp',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5fb2s5apgw6nw' => array(
                            'key' => 'layout_5fb2s5apgw6nw',
                            'name' => 'address-telephones',
                            'label' => 'Address & Telephones Block',
                            'display' => 'block',
                            'sub_fields'  => array(
                                array(
                                    'key' => 'field_5f07d0275b8c0',
                                    'label' => 'Main Message',
                                    'name' => 'main_message',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5f07d0315b8c1',
                                    'label' => 'Sub Message',
                                    'name' => 'sub_message',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5f07cc1451ded',
                                    'label' => 'Telephones block',
                                    'name' => 'telephones_block',
                                    'type' => 'group',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'layout' => 'block',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5ft8dzmaa55tx',
                                            'label' => 'Telephone and E-Mail Section Title',
                                            'name' => 'telephone_and_email_section_title',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5f07cc3a51dee',
                                            'label' => 'Countries',
                                            'name' => 'countries',
                                            'type' => 'repeater',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'collapsed' => '',
                                            'min' => 0,
                                            'max' => 0,
                                            'layout' => '',
                                            'button_label' => '',
                                            'sub_fields' => array(
                                                array(
                                                    'key' => 'field_5f07cc5351def',
                                                    'label' => 'Country',
                                                    'name' => 'country',
                                                    'type' => 'text',
                                                    'instructions' => '',
                                                    'required' => 0,
                                                    'conditional_logic' => 0,
                                                    'button_label' => 'Add Country',
                                                    'wrapper' => array(
                                                        'width' => '',
                                                        'class' => '',
                                                        'id' => '',
                                                    ),
                                                    'default_value' => '',
                                                    'placeholder' => '',
                                                    'prepend' => '',
                                                    'append' => '',
                                                    'maxlength' => '',
                                                ),
                                                array(
                                                    'key' => 'field_5f07cce951df8',
                                                    'label' => 'Telephones',
                                                    'name' => 'telephones',
                                                    'type' => 'repeater',
                                                    'instructions' => '',
                                                    'required' => 0,
                                                    'conditional_logic' => 0,
                                                    'wrapper' => array(
                                                        'width' => '',
                                                        'class' => '',
                                                        'id' => '',
                                                    ),
                                                    'collapsed' => '',
                                                    'min' => 0,
                                                    'max' => 0,
                                                    'layout' => '',
                                                    'button_label' => '',
                                                    'sub_fields' => array(
                                                        array(
                                                            'key' => 'field_5f07cd0051df9',
                                                            'label' => 'Telephone',
                                                            'name' => 'telephone',
                                                            'type' => 'text',
                                                            'instructions' => '',
                                                            'required' => 0,
                                                            'conditional_logic' => 0,
                                                            'wrapper' => array(
                                                                'width' => '',
                                                                'class' => '',
                                                                'id' => '',
                                                            ),
                                                            'default_value' => '',
                                                            'placeholder' => '',
                                                            'prepend' => '',
                                                            'append' => '',
                                                            'maxlength' => '',
                                                            'button_label' => 'Add Telephone',
                                                        ),
                                                    ),
                                                ),
                                            ),
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_5f07cd2251dfa',
                                    'label' => 'Addresses',
                                    'name' => 'addresses',
                                    'type' => 'group',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'layout' => 'block',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5f07cd3751dff',
                                            'label' => 'Message',
                                            'name' => 'message',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5f07cd2251dfb',
                                            'label' => 'Countries',
                                            'name' => 'countries',
                                            'type' => 'repeater',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'collapsed' => '',
                                            'min' => 0,
                                            'max' => 0,
                                            'layout' => '',
                                            'button_label' => '',
                                            'sub_fields' => array(
                                                array(
                                                    'key' => 'field_5f07e74614016',
                                                    'label' => 'Country',
                                                    'name' => 'country',
                                                    'type' => 'text',
                                                    'instructions' => '',
                                                    'required' => 1,
                                                    'button_label' => 'Add Country',
                                                    'conditional_logic' => 0,
                                                    'wrapper' => array(
                                                        'width' => '',
                                                        'class' => '',
                                                        'id' => '',
                                                    ),
                                                    'default_value' => '',
                                                    'placeholder' => '',
                                                    'prepend' => '',
                                                    'append' => '',
                                                    'maxlength' => '',
                                                ),
                                                array(
                                                    'key' => 'field_5f07cd2251dfd',
                                                    'label' => 'Offices',
                                                    'name' => 'offices',
                                                    'type' => 'repeater',
                                                    'instructions' => '',
                                                    'required' => 1,
                                                    'conditional_logic' => 0,
                                                    'wrapper' => array(
                                                        'width' => '',
                                                        'class' => '',
                                                        'id' => '',
                                                    ),
                                                    'collapsed' => '',
                                                    'min' => 0,
                                                    'max' => 0,
                                                    'layout' => 'table',
                                                    'button_label' => '',
                                                    'sub_fields' => array(
                                                        array(
                                                            'key' => 'field_5f07cd2251dfe',
                                                            'label' => 'Office',
                                                            'name' => 'office',
                                                            'type' => 'text',
                                                            'instructions' => '',
                                                            'required' => 1,
                                                            'conditional_logic' => 0,
                                                            'wrapper' => array(
                                                                'width' => '',
                                                                'class' => '',
                                                                'id' => '',
                                                            ),
                                                            'default_value' => '',
                                                            'placeholder' => '',
                                                            'prepend' => '',
                                                            'append' => '',
                                                            'maxlength' => '',
                                                            'button_label' => 'Add Office',
                                                        ),
                                                        array(
                                                            'key' => 'field_5f07cd6c51e00',
                                                            'label' => 'Address',
                                                            'name' => 'address',
                                                            'type' => 'text',
                                                            'instructions' => '',
                                                            'required' => 1,
                                                            'conditional_logic' => 0,
                                                            'wrapper' => array(
                                                                'width' => '',
                                                                'class' => '',
                                                                'id' => '',
                                                            ),
                                                            'default_value' => '',
                                                            'placeholder' => '',
                                                            'prepend' => '',
                                                            'append' => '',
                                                            'maxlength' => '',
                                                        ),
                                                    ),
                                                ),
                                            ),
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_ag80nu5qjw2fl',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5f7nz7wx4pzw7' => array(
                            'key' => 'layout_5f7nz7wx4pzw7',
                            'name' => 'cta-with-image',
                            'label' => 'Call to Action With Image',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5fwrk8v246lkn',
                                    'label' => 'Title',
                                    'name' => 'title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fkh5wut19ada',
                                    'label' => 'Description',
                                    'name' => 'description',
                                    'type' => 'wysiwyg',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'tabs' => 'all',
                                    'toolbar' => 'full',
                                    'media_upload' => 1,
                                    'delay' => 0,
                                ),
                                array(
                                    'key' => 'field_5fibqxdm016go',
                                    'label' => 'Image',
                                    'name' => 'image',
                                    'type' => 'image',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'return_format' => 'array',
                                    'preview_size' => 'medium',
                                    'library' => 'all',
                                    'min_width' => '',
                                    'min_height' => '',
                                    'min_size' => '',
                                    'max_width' => '',
                                    'max_height' => '',
                                    'max_size' => '',
                                    'mime_types' => '',
                                ),
                                array(
                                    'key' => 'field_5fmv3sq3c9fji',
                                    'label' => 'Link',
                                    'name' => 'link',
                                    'type' => 'link',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_61uc6xk2x5w4v',
                                    'label' => 'Color',
                                    'name' => 'color',
                                    'type' => 'select',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'choices' => array(
                                        'red' => 'Red',
                                        'grey' => 'Grey',
                                    ),
                                    'default_value' => false,
                                    'allow_null' => 0,
                                    'multiple' => 0,
                                    'ui' => 1,
                                    'ajax' => 0,
                                    'return_format' => 'value',
                                    'placeholder' => '',
                                ),
                                array(
                                    'key' => 'field_61bubjz5eloil',
                                    'label' => 'Image Position',
                                    'name' => 'image_position',
                                    'type' => 'select',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'choices' => array(
                                        'left' => 'Left',
                                        'right' => 'right',
                                    ),
                                    'default_value' => false,
                                    'allow_null' => 0,
                                    'multiple' => 0,
                                    'ui' => 1,
                                    'ajax' => 0,
                                    'return_format' => 'value',
                                    'placeholder' => '',
                                ),
                                array(
                                    'key' => 'field_ag4dypmjp0ubm',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5f748d3c41a95' => array(
                            'key' => 'layout_5f748d3c41a95',
                            'name' => 'left_image_right_text',
                            'label' => 'Left image right text',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5f748d5441a96',
                                    'label' => 'Image',
                                    'name' => 'image',
                                    'type' => 'image',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'return_format' => 'array',
                                    'preview_size' => 'medium',
                                    'library' => 'all',
                                    'min_width' => '',
                                    'min_height' => '',
                                    'min_size' => '',
                                    'max_width' => '',
                                    'max_height' => '',
                                    'max_size' => '',
                                    'mime_types' => '',
                                ),
                                array(
                                    'key' => 'field_5f748d6241a97',
                                    'label' => 'Title',
                                    'name' => 'title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5f748d6b41a98',
                                    'label' => 'Content',
                                    'name' => 'content',
                                    'type' => 'wysiwyg',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'tabs' => 'all',
                                    'toolbar' => 'full',
                                    'media_upload' => 1,
                                    'delay' => 0,
                                ),
                                array(
                                    'key' => 'field_ag9uftuazlbpi',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5fp147uzdfjou' => array(
                            'key' => 'layout_5fp147uzdfjou',
                            'name' => 'tabbed-content',
                            'label' => 'Tabbed Content',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5fj3b3zr1p8g4',
                                    'label' => 'Tabs',
                                    'name' => 'tabs',
                                    'type' => 'repeater',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'collapsed' => '',
                                    'min' => 0,
                                    'max' => 2,
                                    'layout' => 'block',
                                    'button_label' => 'Add Tab',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5feeoi2pww92a',
                                            'label' => 'Tab Name',
                                            'name' => 'tab-name',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fj2a7q6uvfw5',
                                            'label' => 'Tab Icon Image',
                                            'name' => 'tab-icon',
                                            'type' => 'image',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'medium',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fzohnpa3f0qd',
                                            'label' => 'Tab Title',
                                            'name' => 'tab-title',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fh844jdiukvq',
                                            'label' => 'Tab SubTitle',
                                            'name' => 'tab-subtitle',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fqluxirqqmyo',
                                            'label' => 'Tab Description',
                                            'name' => 'tab-description',
                                            'type' => 'textarea',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                            'rows' => 2,
                                        ),
                                        array(
                                            'key' => 'field_5f87vn1qtj7l4',
                                            'label' => 'Items',
                                            'name' => 'items',
                                            'type' => 'repeater',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'collapsed' => '',
                                            'min' => 0,
                                            'max' => 0,
                                            'layout' => 'table',
                                            'button_label' => 'Add Item',
                                            'sub_fields' => array(
                                                array(
                                                    'key' => 'field_5fvc6dx6q63d3',
                                                    'label' => 'Icon Image',
                                                    'name' => 'icon_image',
                                                    'type' => 'image',
                                                    'instructions' => '',
                                                    'required' => 0,
                                                    'conditional_logic' => 0,
                                                    'wrapper' => array(
                                                        'width' => '',
                                                        'class' => '',
                                                        'id' => '',
                                                    ),
                                                    'return_format' => 'array',
                                                    'preview_size' => 'medium',
                                                    'library' => 'all',
                                                    'min_width' => '',
                                                    'min_height' => '',
                                                    'min_size' => '',
                                                    'max_width' => '',
                                                    'max_height' => '',
                                                    'max_size' => '',
                                                    'mime_types' => '',
                                                ),
                                                array(
                                                    'key' => 'field_5f7hj4xipueav',
                                                    'label' => 'Title',
                                                    'name' => 'title',
                                                    'type' => 'text',
                                                    'instructions' => '',
                                                    'required' => 0,
                                                    'conditional_logic' => 0,
                                                    'wrapper' => array(
                                                        'width' => '',
                                                        'class' => '',
                                                        'id' => '',
                                                    ),
                                                    'default_value' => '',
                                                    'placeholder' => '',
                                                    'prepend' => '',
                                                    'append' => '',
                                                    'maxlength' => '',
                                                ),
                                                array(
                                                    'key' => 'field_5fa01i902u5gt',
                                                    'label' => 'Description',
                                                    'name' => 'description',
                                                    'type' => 'textarea',
                                                    'instructions' => '',
                                                    'required' => 0,
                                                    'conditional_logic' => 0,
                                                    'wrapper' => array(
                                                        'width' => '',
                                                        'class' => '',
                                                        'id' => '',
                                                    ),
                                                    'default_value' => '',
                                                    'placeholder' => '',
                                                    'prepend' => '',
                                                    'append' => '',
                                                    'maxlength' => '',
                                                    'rows' => 4,
                                                ),
                                            ),
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_agkk36wp6wwco',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5f1guz7zy08s6' => array(
                            'key' => 'layout_5f1guz7zy08s6',
                            'name' => 'title-three-columns-icon-and-text-list',
                            'label' => 'Title And Three Columns Icon And Text List',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5fhqcghuaduoj',
                                    'label' => 'Title',
                                    'name' => 'title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fujjwklxrmnp',
                                    'label' => 'Subtitle',
                                    'name' => 'subtitle',
                                    'type' => 'textarea',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                    'rows' => 2,
                                ),
                                array(
                                    'key' => 'field_5fxxfs5rwu8h2',
                                    'label' => 'Items',
                                    'name' => 'items',
                                    'type' => 'repeater',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'collapsed' => '',
                                    'min' => 0,
                                    'max' => 0,
                                    'layout' => 'table',
                                    'button_label' => '',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5fc51dojn54sp',
                                            'label' => 'Icon Image',
                                            'name' => 'icon_image',
                                            'type' => 'image',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'medium',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fyjhfi9812rf',
                                            'label' => 'Title',
                                            'name' => 'title',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fs9uvelrlqf3',
                                            'label' => 'Description',
                                            'name' => 'description',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_agnf904d0nhy0',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5fmcsityxccpv' => array(
                            'key' => 'layout_5fmcsityxccpv',
                            'name' => 'image-boxes-three-columns',
                            'label' => 'Image Boxes Three Columns',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5fwbd9f0kbhqx',
                                    'label' => 'Boxes',
                                    'name' => 'boxes',
                                    'type' => 'repeater',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'collapsed' => '',
                                    'min' => 0,
                                    'max' => 0,
                                    'layout' => 'table',
                                    'button_label' => '',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5f7f7fzkhbzzs',
                                            'label' => 'Image',
                                            'name' => 'image',
                                            'type' => 'image',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'medium',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fnw4nbwy0q0a',
                                            'label' => 'FlatIcon Class',
                                            'name' => 'flat_icon_class',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'medium',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                        array(
                                            'key' => 'field_5f5n4ngw2jp6i',
                                            'label' => 'Title',
                                            'name' => 'title',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fqf0e8w6aam4',
                                            'label' => 'Link',
                                            'name' => 'link',
                                            'type' => 'link',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_aguuar91gfrrx',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5flgjksf34twl' => array(
                            'key' => 'layout_5flgjksf34twl',
                            'name' => 'title-and-three-columns-boxes-d-two',
                            'label' => 'Title And 3 Columns Boxes Design Two',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_9u1bptwjhiw',
                                    'label' => 'Title',
                                    'name' => 'title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_9u6hhqqj3qum1',
                                    'label' => 'Title Line Two',
                                    'name' => 'title_line_two',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fh7ii4489lk4',
                                    'label' => 'Sub Title',
                                    'name' => 'sub-title',
                                    'type' => 'textarea',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                    'rows' => 2,
                                    'new_lines' => '',
                                ),
                                array(
                                    'key' => 'field_5fjinmiaufhxa',
                                    'label' => 'Boxes',
                                    'name' => 'boxes',
                                    'type' => 'repeater',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'collapsed' => '',
                                    'min' => 0,
                                    'max' => 0,
                                    'layout' => 'table',
                                    'button_label' => '',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5fcx4az956jk8',
                                            'label' => 'Icon Image',
                                            'name' => 'icon',
                                            'type' => 'image',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'medium',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fkra2q0j8v85',
                                            'label' => 'Title',
                                            'name' => 'Title',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fsrrgzc6an8c',
                                            'label' => 'Description',
                                            'name' => 'description',
                                            'type' => 'wysiwyg',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'tabs' => 'all',
                                            'toolbar' => 'full',
                                            'media_upload' => 1,
                                            'delay' => 0,
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_ag2qs90ypjr7i',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5f11c6sqt8cu2' => array(
                            'key' => 'layout_5f11c6sqt8cu2',
                            'name' => 'title-and-three-columns-boxes',
                            'label' => 'Title And 3 Columns Boxes',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5ffbdzc7tp1hr',
                                    'label' => 'Title',
                                    'name' => 'title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fwv56m0h3d8x',
                                    'label' => 'Sub Title',
                                    'name' => 'sub-title',
                                    'type' => 'textarea',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                    'rows' => 2,
                                    'new_lines' => '',
                                ),
                                array(
                                    'key' => 'field_5fgj03qejb4h6',
                                    'label' => 'Boxes',
                                    'name' => 'boxes',
                                    'type' => 'repeater',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'collapsed' => '',
                                    'min' => 0,
                                    'max' => 0,
                                    'layout' => 'table',
                                    'button_label' => '',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5fkloc0m513o6',
                                            'label' => 'Icon image',
                                            'name' => 'icon',
                                            'type' => 'image',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'medium',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fjt5qjtiv44b',
                                            'label' => 'Title',
                                            'name' => 'Title',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fb62otbwkq0e',
                                            'label' => 'Description',
                                            'name' => 'description',
                                            'type' => 'wysiwyg',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'tabs' => 'all',
                                            'toolbar' => 'full',
                                            'media_upload' => 1,
                                            'delay' => 0,
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_agiqnudom0v9v',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5fgjltjwir251' => array(
                            'key' => 'layout_5fgjltjwir251',
                            'name' => 'gallery-carousel',
                            'label' => 'Gallery Carousel',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5f1bjheayhsop',
                                    'label' => 'Images',
                                    'name' => 'images',
                                    'type' => 'repeater',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'collapsed' => '',
                                    'min' => 0,
                                    'max' => 0,
                                    'layout' => 'table',
                                    'button_label' => '',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5f5e3kg1q7v56',
                                            'label' => 'Image',
                                            'name' => 'image',
                                            'type' => 'image',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'medium',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fvt1fkbkccrc',
                                            'label' => 'Name',
                                            'name' => 'name',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fx0111yr0s6h',
                                            'label' => 'Position',
                                            'name' => 'position',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fmwc8wfd96nr',
                                            'label' => 'LinkedIn URL',
                                            'name' => 'linkedin-url',
                                            'type' => 'url',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_agnszfhkvy1av',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5fbp6i65q2gzq' => array(
                            'key' => 'layout_5fbp6i65q2gzq',
                            'name' => 'title-free-content-white-bg',
                            'label' => 'Title And Free Content No Background',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5f4mkrdswq149',
                                    'label' => 'Title',
                                    'name' => 'title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5f0u62ijncdsy',
                                    'label' => 'Sub Title (Optional)',
                                    'name' => 'sub_title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5f2ne93p6noc2',
                                    'label' => 'Content',
                                    'name' => 'content',
                                    'type' => 'wysiwyg',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'tabs' => 'all',
                                    'toolbar' => 'full',
                                    'media_upload' => 1,
                                    'delay' => 0,
                                ),
                                array(
                                    'key' => 'field_ag1ytnxb960cy',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5f6c768a86660' => array(
                            'key' => 'layout_5f6c768a86660',
                            'name' => 'title_and_free_content',
                            'label' => 'Title And Free Content',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5f6c76e5e7221',
                                    'label' => 'data',
                                    'name' => 'data',
                                    'type' => 'repeater',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'collapsed' => '',
                                    'min' => 0,
                                    'max' => 0,
                                    'layout' => 'table',
                                    'button_label' => '',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5f6c7717e7222',
                                            'label' => 'Title',
                                            'name' => 'title',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5f6c771ee7223',
                                            'label' => 'Content',
                                            'name' => 'content',
                                            'type' => 'wysiwyg',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'tabs' => 'all',
                                            'toolbar' => 'full',
                                            'media_upload' => 1,
                                            'delay' => 0,
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_5f75a68233334',
                                    'label' => 'Secondary bg',
                                    'name' => 'secondary_bg',
                                    'type' => 'true_false',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'message' => '',
                                    'default_value' => 0,
                                    'ui' => 0,
                                    'ui_on_text' => '',
                                    'ui_off_text' => '',
                                ),
                                array(
                                    'key' => 'field_agk1yiiughu73',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5f6c82cfe7241' => array(
                            'key' => 'layout_5f6c82cfe7241',
                            'name' => 'left_text_right_image',
                            'label' => 'Left Text Right Image',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5f6c82fee7242',
                                    'label' => 'Title',
                                    'name' => 'title',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5f6c830ee7243',
                                    'label' => 'Description',
                                    'name' => 'description',
                                    'type' => 'wysiwyg',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'tabs' => 'all',
                                    'toolbar' => 'full',
                                    'media_upload' => 1,
                                    'delay' => 0,
                                ),
                                array(
                                    'key' => 'field_5f6c831fe7244',
                                    'label' => 'Image',
                                    'name' => 'first_image',
                                    'type' => 'image',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'return_format' => 'array',
                                    'preview_size' => 'medium',
                                    'library' => 'all',
                                    'min_width' => '',
                                    'min_height' => '',
                                    'min_size' => '',
                                    'max_width' => '',
                                    'max_height' => '',
                                    'max_size' => '',
                                    'mime_types' => '',
                                ),
                                array(
                                    'key' => 'field_5fymw9v4fmzef',
                                    'label' => 'Button',
                                    'name' => 'button',
                                    'type' => 'link',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'return_format' => 'array',
                                ),
                                array(
                                    'key' => 'field_ag55u0gok731x',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5flxgkq3txgid' => array(
                            'key' => 'layout_5flxgkq3txgid',
                            'name' => 'call_to_action_large_one',
                            'label' => 'Call To Action Large One',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5f3jgxte83wf2',
                                    'label' => 'Header',
                                    'name' => 'header',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fwbm38rnlelm',
                                    'label' => 'Text',
                                    'name' => 'text',
                                    'type' => 'wysiwyg',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'tabs' => 'all',
                                    'toolbar' => 'full',
                                    'media_upload' => 1,
                                    'delay' => 0,
                                ),
                                array(
                                    'key' => 'field_5ft1w45xdq1kv',
                                    'label' => 'Button',
                                    'name' => 'button',
                                    'type' => 'link',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5f7d7bwuhgpr4',
                                    'label' => 'Background image',
                                    'name' => 'background_image',
                                    'type' => 'image',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'return_format' => 'array',
                                    'preview_size' => 'medium',
                                    'library' => 'all',
                                    'min_width' => '',
                                    'min_height' => '',
                                    'min_size' => '',
                                    'max_width' => '',
                                    'max_height' => '',
                                    'max_size' => '',
                                    'mime_types' => '',
                                ),
                                array(
                                    'key' => 'field_ag4k1g8vdlepd',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5fzwlvsvg0kp9' => array(
                            'key' => 'layout_5fzwlvsvg0kp9',
                            'name' => 'call_to_action_one',
                            'label' => 'Call To Action One',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5f821pkl3i5a9',
                                    'label' => 'Header',
                                    'name' => 'header',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fjnik7igbuxo',
                                    'label' => 'Text',
                                    'name' => 'text',
                                    'type' => 'wysiwyg',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'tabs' => 'all',
                                    'toolbar' => 'full',
                                    'media_upload' => 0,
                                    'delay' => 0,
                                ),
                                array(
                                    'key' => 'field_5fgjxc44ohsgw',
                                    'label' => 'Button',
                                    'name' => 'button',
                                    'type' => 'link',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_agdi7tyoxck5z',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5f6c8137e7231' => array(
                            'key' => 'layout_5f6c8137e7231',
                            'name' => 'testimonials',
                            'label' => 'Testimonials',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5f6c8172e7235',
                                    'label' => 'Title Line One',
                                    'name' => 'title_line_one',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fvstt8mm4a87',
                                    'label' => 'Title Line Two',
                                    'name' => 'title_line_two',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fdxkkv7mivrn',
                                    'label' => 'Title Line Three',
                                    'name' => 'title_line_three',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5f6c814ce7232',
                                    'label' => 'Testimonial',
                                    'name' => 'testimonial',
                                    'type' => 'repeater',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'collapsed' => '',
                                    'min' => 0,
                                    'max' => 0,
                                    'layout' => 'table',
                                    'button_label' => '',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5fxvyce353un4',
                                            'label' => 'Image',
                                            'name' => 'image',
                                            'type' => 'image',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'medium',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                        array(
                                            'key' => 'field_5f6c8172e7234',
                                            'label' => 'Name',
                                            'name' => 'name',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5f6c817ee7235',
                                            'label' => 'Testimonial',
                                            'name' => 'testimonial',
                                            'type' => 'textarea',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fbso2h1pqcu1',
                                            'label' => 'Position',
                                            'name' => 'position',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_5fv5wiarp1lrw',
                                    'label' => 'Right image',
                                    'name' => 'right_image',
                                    'type' => 'image',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'return_format' => 'array',
                                    'preview_size' => 'medium',
                                    'library' => 'all',
                                    'min_width' => '',
                                    'min_height' => '',
                                    'min_size' => '',
                                    'max_width' => '',
                                    'max_height' => '',
                                    'max_size' => '',
                                    'mime_types' => '',
                                ),
                                array(
                                    'key' => 'field_ag3t6qrw7vu7r',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5fnu5pzfcux7x' => array(
                            'key' => 'layout_5fnu5pzfcux7x',
                            'name' => 'gallery_left_content_right',
                            'label' => 'Gallery Left Content Right',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5f6g1wgxe1zot',
                                    'label' => 'Gallery',
                                    'name' => 'gallery',
                                    'type' => 'gallery',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'return_format' => 'array',
                                    'preview_size' => 'medium',
                                    'insert' => 'append',
                                    'library' => 'all',
                                    'min' => '',
                                    'max' => '',
                                    'min_width' => '',
                                    'min_height' => '',
                                    'min_size' => '',
                                    'max_width' => '',
                                    'max_height' => '',
                                    'max_size' => '',
                                    'mime_types' => '',
                                ),
                                array(
                                    'key' => 'field_5ficmgpiw88rm',
                                    'label' => 'Text Line one',
                                    'name' => 'text_line_one',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_576r1fa7pt9f',
                                    'label' => 'Text Line Two',
                                    'name' => 'text_line_two',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5f5rz89t3tdq2',
                                    'label' => 'Text',
                                    'name' => 'text',
                                    'type' => 'wysiwyg',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5f237t361ta90',
                                    'label' => 'Button Link',
                                    'name' => 'button_link',
                                    'type' => 'link',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_agh9p5tr7q8zf',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5fpx2jnsmo66s' => array(
                            'key' => 'layout_5fpx2jnsmo66s',
                            'name' => 'two_cols_text_left_four_images_right',
                            'label' => 'Two Columns Text Left 2 Columns Images Right',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5fghgeu85x790',
                                    'label' => 'Text Line one',
                                    'name' => 'text_line_one',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fi4zl8her733',
                                    'label' => 'Text Line Two',
                                    'name' => 'text_line_two',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5faxg839usyq8',
                                    'label' => 'Text Line Three',
                                    'name' => 'text_line_three',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 3,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fm9g0yx3vgyz',
                                    'label' => 'Text',
                                    'name' => 'text',
                                    'type' => 'wysiwyg',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fpl7ypijhxge',
                                    'label' => 'Button Link',
                                    'name' => 'button_link',
                                    'type' => 'link',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_5fx3kdbohcxlj',
                                    'label' => 'Image Boxes',
                                    'name' => 'image_boxes',
                                    'type' => 'repeater',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'collapsed' => '',
                                    'min' => 0,
                                    'max' => 0,
                                    'layout' => 'table',
                                    'button_label' => '',
                                    'sub_fields' => array(
                                        array(
                                            'key' => 'field_5fm5lnv7geivk',
                                            'label' => 'Image',
                                            'name' => 'image',
                                            'type' => 'image',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'medium',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fxg9ba74nek8',
                                            'label' => 'FlatIcon Class',
                                            'name' => 'flat_icon_class',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'return_format' => 'array',
                                            'preview_size' => 'medium',
                                            'library' => 'all',
                                            'min_width' => '',
                                            'min_height' => '',
                                            'min_size' => '',
                                            'max_width' => '',
                                            'max_height' => '',
                                            'max_size' => '',
                                            'mime_types' => '',
                                        ),
                                        array(
                                            'key' => 'field_5ffwd963d6785',
                                            'label' => 'Title',
                                            'name' => 'title',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fmop4zfh248v',
                                            'label' => 'Description',
                                            'name' => 'description',
                                            'type' => 'text',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                        array(
                                            'key' => 'field_5fs6ocgjy53vm',
                                            'label' => 'Link',
                                            'name' => 'link',
                                            'type' => 'link',
                                            'instructions' => '',
                                            'required' => 0,
                                            'conditional_logic' => 0,
                                            'wrapper' => array(
                                                'width' => '',
                                                'class' => '',
                                                'id' => '',
                                            ),
                                            'default_value' => '',
                                            'placeholder' => '',
                                            'prepend' => '',
                                            'append' => '',
                                            'maxlength' => '',
                                        ),
                                    ),
                                ),
                                array(
                                    'key' => 'field_agguwedmfhkbs',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                        'layout_5fnk485mrvg94' => array(
                            'key' => 'layout_5fnk485mrvg94',
                            'name' => 'banner',
                            'label' => 'Banner',
                            'display' => 'block',
                            'sub_fields' => array(
                                array(
                                    'key' => 'field_5fuswx20bsupu',
                                    'label' => 'Text Line one',
                                    'name' => 'text_line_one',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => 134,
                                ),
                                array(
                                    'key' => 'field_5fiisuxk1riz9',
                                    'label' => 'Text Line Two',
                                    'name' => 'text_line_two',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 1,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => 134,
                                ),
                                array(
                                    'key' => 'field_5fqfyy7n8y7at',
                                    'label' => 'Text Line Three',
                                    'name' => 'text_line_three',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 3,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => 134,
                                ),
                                array(
                                    'key' => 'field_5fb2kbe60si7p',
                                    'label' => 'Button',
                                    'name' => 'button',
                                    'type' => 'link',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                                array(
                                    'key' => 'field_ag2pdfmfz9y3p',
                                    'label' => 'HTML ID',
                                    'name' => 'html_id',
                                    'type' => 'text',
                                    'instructions' => '',
                                    'required' => 0,
                                    'conditional_logic' => 0,
                                    'wrapper' => array(
                                        'width' => '',
                                        'class' => '',
                                        'id' => '',
                                    ),
                                    'default_value' => '',
                                    'placeholder' => '',
                                    'prepend' => '',
                                    'append' => '',
                                    'maxlength' => '',
                                ),
                            ),
                            'min' => '',
                            'max' => '',
                        ),
                    ),
                    'button_label' => 'Add Layout',
                    'min' => '',
                    'max' => '',
                ),
            ),
            'location' => array(
                array(
                    array(
                        'param' => 'post_type',
                        'operator' => '==',
                        'value' => 'page',
                    ),
                ),
            ),
            'menu_order' => 0,
            'position' => 'normal',
            'style' => 'default',
            'label_placement' => 'top',
            'instruction_placement' => 'label',
            'hide_on_screen' => '',
            'active' => true,
            'description' => '',
        ));
    endif;
}

add_action('acf/init', __NAMESPACE__ . '\\flairstech_acf_add_theme_general_template_fields');

function flairstech_acf_add_theme_top_menu_fields()
{
    if (function_exists('acf_add_local_field_group')) :
        acf_add_local_field_group(array(
            'key' => 'group_5f6c87446xkyf',
            'title' => 'General',
            'fields' => array(
                array(
                    'key' => 'field_5f6c8905c7032',
                    'label' => 'Menu Icon Class',
                    'name' => 'menu_icon',
                    'type' => 'text',
                    'instructions' => '',
                    'required' => 0,
                    'conditional_logic' => 0,
                    'wrapper' => array(
                        'width' => '',
                        'class' => '',
                        'id' => '',
                    ),
                    'default_value' => '',
                    'placeholder' => '',
                    'prepend' => '',
                    'append' => '',
                    'maxlength' => '',
                ),
            ),
            'location' => array(
                array(
                    array(
                        'param' => 'nav_menu_item',
                        'operator' => '==',
                        'value' => 'location/secondary_navigation',
                    ),
                ),
            ),
            'menu_order' => 0,
            'position' => 'normal',
            'style' => 'default',
            'label_placement' => 'top',
            'instruction_placement' => 'label',
            'hide_on_screen' => '',
            'active' => true,
            'description' => '',
        ));
    endif;
}

add_action('acf/init', __NAMESPACE__ . '\\flairstech_acf_add_theme_top_menu_fields');

function flairstech_acf_add_post_image_fields()
{
    if (function_exists('acf_add_local_field_group')) :
        acf_add_local_field_group(array(
            'key' => 'group_5f7o2ifyydd7r',
            'title' => 'Post Fields',
            'fields' => array(
                array(
                    'key' => 'field_5f733y0f3073n',
                    'label' => 'Sub Header',
                    'name' => 'sub_header',
                    'type' => 'text',
                    'instructions' => '',
                    'required' => 0,
                    'conditional_logic' => 0,
                    'wrapper' => array(
                        'width' => '',
                        'class' => '',
                        'id' => '',
                    ),
                    'default_value' => '',
                    'placeholder' => '',
                    'prepend' => '',
                    'append' => '',
                    'maxlength' => '',
                ),
            ),
            'location' => array(
                array(
                    array(
                        'param' => 'post_type',
                        'operator' => '==',
                        'value' => 'post',
                    ),
                ),
            ),
            'menu_order' => 0,
            'position' => 'normal',
            'style' => 'default',
            'label_placement' => 'top',
            'instruction_placement' => 'label',
            'hide_on_screen' => '',
            'active' => true,
            'description' => '',
        ));
    endif;
}

add_action('acf/init', __NAMESPACE__ . '\\flairstech_acf_add_post_image_fields');
